{% extends 'base.html' %}

{% block title %}{{ name }}{% endblock %}

{% block body %}
<h1>[[ {{ name }} ]]</h1>


{{content}}

<hr>
<br />
<button type="button" value="text" accesskey="E" onClick="javascript:parent.location='/edit/{{name}}';">edit {{name}}</button>

{% endblock %}
