<html>
    <head>
        <title>Juno has found a 404!</title>
    </head>
    <body>
        <div>The page you requested doesn't exist:</div>
        <div>Explanation: {{ error }} ${ error }</div>
    </body>
</html>
